@@ -19,10 +19,6 @@ class Venue():
         self.VENUE_PATH in sys.path or sys.path.insert(0,self.VENUE_PATH)
         self.get_settings()
 
-    def __unicode__(self):
-        s = 'Django Backstage Venue named %s at %s' % (self.VENUE_NAME, self.VENUE_PATH)
-        return s
-
     def get_settings(self):
         """ import the venue's settings.py"""
         try:
@@ -137,6 +133,10 @@ class Venue():
             print 'error'
         return
 
+    def __unicode__(self):
+        s = 'Backstage Venue instance %s at %s' % (self.VENUE_NAME, self.VENUE_ROOT)
+        return s
+
 def copy_venue_skel(venue_path):
     """Populate a (usually) new backstage venue with the contents of backstage/skel"""
     skeldir = os.path.join(os.path.dirname(backstage.__file__),'skel/venue')
